# eric7.MicroPython.MipPackageDialog

Module implementing a dialog to enter the package data for 'mip'.

### Global Attributes

None

### Classes

MipPackageDialog | Class implementing a dialog to enter the package data for 'mip'.

### Functions

None

## MipPackageDialog

Class implementing a dialog to enter the package data for 'mip'.

### Derived from

QDialog, Ui_MipPackageDialog

### Class Attributes

None

### Class Methods

None

### Methods

MipPackageDialog | Constructor
__updateOk | Private slot to set the enabled state of the OK button.
getData | Public method to get the entered package installation data.

### Static Methods

None

#### MipPackageDialog (Constructor)

MipPackageDialog(parent=None)

Constructor

parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### MipPackageDialog.__updateOk

__updateOk()

Private slot to set the enabled state of the OK button.

#### MipPackageDialog.getData

getData()

Public method to get the entered package installation data.

Return:
  tuple containing the package name, package version and a flag, indicating to install the package as '.mpy ' files

Return Type:
  tuple of (str, str, bool)

Up